Index: /trunk/psLib/test/collections/tst_psBitSet_06.c
===================================================================
--- /trunk/psLib/test/collections/tst_psBitSet_06.c	(revision 956)
+++ /trunk/psLib/test/collections/tst_psBitSet_06.c	(revision 957)
@@ -7,10 +7,11 @@
  *     B)  Perform invalid binary operation with psBitSets
  *     C)  Attempt to create negative size bitset
- *     D)  Free psBitSets
+ *     D   Attempt to free null BitSet
+ *     E)  Free psBitSets
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-06-09 21:18:53 $
+ *  @version $Revision: 1.5 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-09 21:29:56 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -55,5 +56,12 @@
 
 
-    // Test D - Free psBitSets
+    // Test D - Attempt to free null BitSet
+    printNegativeTestHeader(stdout,"psBitSet", "Attempt to free null BitSet",
+                            "Null psBitSet for inBitSet argument", 0);
+    psBitSetFree(NULL);
+    printFooter(stdout, "psBitSet", "Attempt to free null BitSet", true);
+
+
+    // Test E - Free psBitSets
     printPositiveTestHeader(stdout, "psBitSet", "Free psBitSets");
     psBitSetFree(bs1);
